;**************************************************************************
;* FileName	: MATH.ASM
;* Date 	: 10.10.2002
;* File version : v1.00
;*
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.fw.hu
;* E-mail	: majki@fw.hu
;*
;*-------------------------------------------------------------------------
;*
;* Description	: Math
;*		  ==================================
;*		  Testcode for math module
;*
;*
;*-------------------------------------------------------------------------
;*
;* Connections	:	       _______	 _______
;*			      |       \_/	|
;*		       n.c. ==| RA2	    RA1 |== n.c.
;*		       n.c. ==| RA3	    RA0 |== n.c.
;*		       n.c. ==| RA4	   OSC1 |== quartz1
;*		     -reset ==|-MCLR	   OSC2 |== quartz2
;*			GND ==| Vss	    Vdd |== +5V
;*		       n.c. ==| RB0	    RB7 |== n.c.
;*		       n.c. ==| RB1	    RB6 |== n.c.
;*		       n.c. ==| RB2	    RB5 |== n.c.
;*		       n.c. ==| RB3	    RB4 |== n.c.
;*			      |_________________|
;*				   PIC16F84 
;*
;*-------------------------------------------------------------------------
;*
;* Resource	: Ports 	  :    xx /   13 pin   (   %)
;*		  Data memory	  :    xx /   68 byte  (   %)
;*		  Prog memory	  :   xxx / 1024 word  (   %)
;*		  Timer0	  : 
;*		  Interrupt	  : 
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  10/10/2002 	Initial Release
;*
;**************************************************************************

	list	p=16f84, r=dec, l=0

;***** INCLUDES ***********************************************************

	include "p16f84.inc"
	include "..\..\modules\base.inc"

;***** CONFIG ************************************************************

	__CONFIG _XT_OSC & _WDT_OFF & _PWRTE_ON & _CP_OFF
	__IDLOCS 0100h			; version

	EXPAND_MACROS	EXP_COND	; macro expansion mode

;***** DEFINES ************************************************************
#define DEBUG				; for some debug message
;#define NO_DELAY			; for fast simulation
;#define NO_RS232			; for fast simulation

xtal_freq	EQU	4 MHz	  	; crystal frequency
core_freq	EQU	xtal_freq/4	; core operating frequency

;#define	MATH_OPTSPEED

; ----- porta -------------------------------------------------------------

#define		PORTA_0		PORTA,0		; free
#define		PORTA_1		PORTA,1		; free
#define		PORTA_2		PORTA,2		; free
#define		PORTA_3		PORTA,3		; free
#define		PORTA_4		PORTA,4		; free (open drain!)

; ----- portb -------------------------------------------------------------

#define		PORTB_0		PORTB,0		; free
#define		PORTB_1		PORTB,1		; free
#define		PORTB_2		PORTB,2		; free
#define		PORTB_3		PORTB,3		; free
#define		PORTB_4		PORTB,4		; free
#define		PORTB_5		PORTB,5		; free
#define		PORTB_6		PORTB,6		; free
#define		PORTB_7		PORTB,7		; free


;***** MACROS *************************************************************

	include "..\..\modules\math.mac"


;***** CONSTANT DEFINITIONS ***********************************************

option_val	EQU	00000010b	; Timer source : intclk / 8
trisa_val	EQU	00011111b	; TRISA value (all input)
trisb_val	EQU	11111111b	; TRISB value (all input)
intcon_val	EQU	00100000b	; Interrupt control




;***** VARIABLE DEFINITIONS ***********************************************
	cblock	0Ch
		w_temp			; variable used for context saving
		status_temp		; variable used for context saving
		fsr_temp		; variable used for context saving

		TEMP			; dummy register

		
		A8, B8
		A16:2, B16:2		


		x
		y
		x16:2
		y16:2


	endc




;***** ENTRY POINT ********************************************************
		ORG	000h		; processor reset vector
		clrwdt
		clrf	PORTA		; clear latch
		clrf	PORTB		; clear latch
		goto	start


;***** IT HANDLER *********************************************************
;* Interrupt handler
;* <comment>
;**************************************************************************
		ORG	004h		; interrupt vector location
		movwf	w_temp		; save off current W register contents
		swapf	STATUS,w	; move STATUS register into W register
		movwf	status_temp	; save off contents of STATUS register

		movf	FSR,w		; save FSR
		movwf	fsr_temp
;--------------------------------------------------------------------------

		; <IT Code>

;--------------------------------------------------------------------------
		movf	fsr_temp,w	; restore FSR
		movwf	FSR

		swapf	status_temp,w	; retrieve copy of STATUS register
		movwf	STATUS		; restore pre-isr STATUS register contents
		swapf	w_temp,f
		swapf	w_temp,w	; restore pre-isr W register contents
		retfie			; return from interrupt




;***** REAL PROGRAM START *************************************************
start

		MOVC8	A8, 100
		MOV8	B8, A8

		MOVC16	A16, 100
		MOV16	B16, A16

		INC8	A8
		DEC8	B8

		INC16	A16
		DEC16	B16

		NEG8	A8
		NEG16	A16

		CLR8	A8
		CLR16	A16
		
		SHR8	B8
		SHL8	B8

		SHR16	B16
		SHL16	B16
		
		ADDC8	A8, 10
		ADD8	A8, B8

		ADDC16	A16, 10
		ADD16	A16, B16
		
		SUBC8	A8, 10
		SUB8	A8, B8

		SUBC16	A16, 10
		SUB16	A16, B16

		CMPC8	A8, 100
		JE	$+1

		CMP8	A8, B8
		JNE	$+1

		CMPC16	A16, 100
		JA	$+1

		CMP16	A16, B16
		JNA	$+1


		MOVC8	AARG8, 123
		MOVC8	BARG8, 234
		MUL8


		MOVC8	AARG8, 123
		MOVC8	BARG8, 234
		DIV8

		MOVC16	AARG16, 123
		MOVC16	BARG16, 234
		MUL16


		MOVC16	AARG16, 123
		MOVC16	BARG16, 234
		DIV16


		movlw	123		
		BIN2BCD8

		MOVC8	A8, 234
		BIN2BCD8I A8


		MOVC16 BARG16, 12345
		BIN2BCD16

		MOVC16	A16, 23456
		BIN2BCD16I A16
		






;----- set configuration --------------------------------------------------
		bank1
		ERRORLEVEL -302
		movlw	option_val
		movwf	OPTION_REG	; set OPTION_REG
		movlw	trisa_val
		movwf	TRISA		; set TRISA
		movlw	trisb_val
		movwf	TRISB		; set TRISB

		bank0
		ERRORLEVEL +302
		movlw	intcon_val	
		movwf	INTCON		; set INTCON


;----- main cycle  --------------------------------------------------------


		
main_cycle	nop


		goto	main_cycle






;***** SUB1 ***************************************************************
;* 
;* Input :              		; 
;* Output:  				; 
;* Clock :   
;**************************************************************************

sub1 


		return

;**************************************************************************

	include "..\..\modules\math.inc"

	end				  ; end of program








